# tiny-agent-α


### Installation
```bash
pip install dria_agent
```
To use MLX as backend
```bash
pip install 'dria_agent[mlx]'
```
For HuggingFace backend
```bash
pip install 'dria_agent[huggingface]'
```

In order to use extra tooling select a backend (e.g. mlx) and run:
```bash
pip install 'dria_agent[mlx, tools]'
```

a fast and powerful tool calling model designed to run on edge devices.

3B 8bit high performance and quality [download](https://huggingface.co/driaforall/Tiny-Agent-a-3B/resolve/main/dria-agent-a-3b.Q8_0.gguf?download=true)

3B 4bit balanced performance and speed [download](https://huggingface.co/driaforall/Tiny-Agent-a-3B/resolve/main/dria-agent-a-3b.Q4_K_M.gguf?download=true)

1.5B 8bit fast CPU inference [download](https://huggingface.co/driaforall/Tiny-Agent-a-1.5B/resolve/main/dria-agent-a-1.5b.Q8_0.gguf?download=true)

1.5B 4bit faster CPU inference [download](https://huggingface.co/driaforall/Tiny-Agent-a-1.5B/resolve/main/dria-agent-a-1.5b.Q8_0.gguf?download=true)

0.5B 8bit ultra-light [download](https://huggingface.co/driaforall/Tiny-Agent-a-1.5B/resolve/main/dria-agent-a-1.5b.Q4_K_M.gguf?download=true)


